# moduledocs

[![Build Status](https://travis-ci.org/machineandme/moduledocs.svg?branch=master)](https://travis-ci.org/machineandme/moduledocs)

Static documentation extraction tool for python language.

Supports markdown and html.
